@@ -65,89 +65,6 @@ MenuValueT = Union[None, str, GLib.Variant, VariantMixin]
 MenuItemListT = list[tuple[str, str, MenuValueT]]
 
 
-class NickCompletionGenerator:
-    def __init__(self, self_nick: str) -> None:
-        self.nick = self_nick
-        self.sender_list: list[str] = []
-        self.attention_list: list[str] = []
-
-    def change_nick(self, new_nick: str) -> None:
-        self.nick = new_nick
-
-    def record_message(self, contact: str, highlight: bool) -> None:
-        if contact == self.nick:
-            return
-
-        log.debug('Recorded a message from %s, highlight; %s', contact,
-                  highlight)
-        if highlight:
-            try:
-                self.attention_list.remove(contact)
-            except ValueError:
-                pass
-            if len(self.attention_list) > 6:
-                self.attention_list.pop(0)  # remove older
-            self.attention_list.append(contact)
-
-        # TODO implement it in a more efficient way
-        # Currently it's O(n*m + n*s), where n is the number of participants and
-        # m is the number of messages processed, s - the number of times the
-        # suggestions are requested
-        #
-        # A better way to do it would be to keep a dict: contact -> timestamp
-        # with expected O(1) insert, and sort it by timestamps in O(n log n)
-        # for each suggestion (currently generating the suggestions is O(n))
-        # this would give the expected complexity of O(m + s * n log n)
-        try:
-            self.sender_list.remove(contact)
-        except ValueError:
-            pass
-        self.sender_list.append(contact)
-
-    def contact_renamed(self, contact_old: str, contact_new: str) -> None:
-        log.debug('Contact %s renamed to %s', contact_old, contact_new)
-        for lst in (self.attention_list, self.sender_list):
-            for idx, contact in enumerate(lst):
-                if contact == contact_old:
-                    lst[idx] = contact_new
-
-    def generate_suggestions(self, nicks: list[str],
-                             beginning: str) -> list[str]:
-        """
-        Generate the order of suggested MUC autocompletions
-
-        `nicks` is the list of contacts currently participating in a MUC
-        `beginning` is the text already typed by the user
-        """
-        def nick_matching(nick: str) -> bool:
-            return nick != self.nick \
-                and nick.lower().startswith(beginning.lower())
-
-        if beginning == '':
-            # empty message, so just suggest recent mentions
-            potential_matches = self.attention_list
-        else:
-            # nick partially typed, try completing it
-            potential_matches = self.sender_list
-
-        potential_matches_set = set(potential_matches)
-        log.debug('Priority matches: %s', potential_matches_set)
-
-        matches = [n for n in potential_matches if nick_matching(n)]
-        # the most recent nick is the last one on the list
-        matches.reverse()
-
-        # handle people who have not posted/mentioned us
-        other_nicks = [
-            n for n in nicks
-            if nick_matching(n) and n not in potential_matches_set
-        ]
-        other_nicks.sort(key=str.lower)
-        log.debug('Other matches: %s', other_nicks)
-
-        return matches + other_nicks
-
-
 def set_urgency_hint(window: Gtk.Window, setting: bool) -> None:
     if app.settings.get('use_urgency_hint'):
         window.set_urgency_hint(setting)
